# ImageRotator/__main__.py
import os
import argparse
import logging
import sys
from ImageRotator.RotateImage import RotateImage

Logger = logging.getLogger(__name__)

def parseArgs():
    try:
        parser = argparse.ArgumentParser(description="Rotate dicom images by an angle configured.\n Default rotation angle is 90°")

        parser.add_argument('-i', '--inputdir',  help='Folder which contains dicom images', required=True)
        parser.add_argument('-o','--outputdir', help='Folder to store result images', required=True)
        parser.add_argument('-l','--logdir',    help='Folder to store log files', required = True)
        parser.add_argument('-c','--configdir', help='Folder which contains configuration files', required=True)
        return parser.parse_args()
    except SystemExit:
        sys.exit(1)

def InitializeLogger(logDirPath):
    if os.path.exists(logDirPath):
        logFile = os.path.join(logDirPath,'DicomImageRotator.log')
        logging.basicConfig(filename=logFile, 
                                filemode= 'w',
                                level=logging.INFO,
                                format='%(asctime)s - %(name)s - %(lineno)d - %(levelname)s - %(message)s',
                                datefmt='%d-%b-%y %H:%M:%S')

def InvokeRotation(args):
    rotateImage = RotateImage(args.inputdir,args.outputdir, args.configdir)
    return rotateImage.main()

def main():
    #Parse command line arguments
    args = parseArgs()

    if args is not None:
        #Setup logging
        if args.logdir is not None:
            InitializeLogger(args.logdir)
        for arg in vars(args):
            Logger.info('Argument: %s Value: %s', arg, getattr(args, arg))

        #Invoke dicom image rotation
        return InvokeRotation(args)

    
    
